@@ -7,7 +7,7 @@ import uuid
 import webbrowser
 
 from keycloak import KeycloakOpenID
-from qiskit.qpy import dump
+from qiskit import qpy
 from qiskit import QuantumCircuit
 from urllib.parse import urlencode
 
@@ -62,7 +62,7 @@ class InputData:
 
     def serialize_circuit(self, qc):
         buffer = io.BytesIO()
-        dump([qc], buffer)
+        qpy.dump(qc, buffer)
         qpy_binary_data = buffer.getvalue()
         base64_encoded_circuit = base64.b64encode(qpy_binary_data).decode("utf-8")
         return base64_encoded_circuit
